<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2018.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
Name:
	calendar_widget_events_by_date_range_rh.cfm
Summary:
	Render Handler to render an events list for specific date range
ADF App:
	pt_calendar
History:
	2016-09-29 - GAC - Created
--->

<!--- if this module loads resources, do it here.. --->
<!---<cfscript>
	// none
</cfscript>--->

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
  <cfexit>
</cfif>

<cfscript>
	// Uncomment this for development only. The render handler should be cached. No dynamic data from url parameters etc.
	//request.element.isStatic = 0;

// START - Cache until 2:30:00 AM each day
	validTillTime = "02:30:00"; // time cacheTill as 24-hr clock value

	currentDT = Now();
	todayD = DateFormat( currentDT , "yyyy-mm-dd" );
	nowDT = todayD & " " & TimeFormat( currentDT , "HH:mm:ss" );
	validTillTodayDT = todayD & " " & validTillTime;

	tomorrowD = DateFormat( DateAdd( 'd', 1, todayD ), "yyyy-mm-dd" );
	validTillTomorrowDT = tomorrowD & " " & validTillTime;

	validTodayCompare = DateCompare(nowDT,validTillTodayDT);
	validTomorrowCompare = DateCompare(nowDT,validTillTomorrowDT);

	if ( validTodayCompare LTE 0 AND validTomorrowCompare EQ -1 )
		cacheValidUntilDT = validTillTodayDT;
	else
		cacheValidUntilDT = validTillTomorrowDT;

	request.element.cacheValidUntil = cacheValidUntilDT;

	// - Make sure that the element is static
	request.element.isStatic = 1;
// END - Cache until 2:30 AM each day
</cfscript>

<cfscript>
	// Get the Configuration and Page Map Values
	appConfig = application.ptCalendar.getAppConfig();
	
	cfDateDisplayMask = application.ptCalendar.getDisplayCFdateMask(); 			// "M/D/YYYY" - DATE FORMAT FOR DISPLAY
	cfDateLongDisplayMask = application.ptCalendar.getDisplayCFdateLongMask(); 	// "dddd mmmm d, yyyy" - DATE FORMAT FOR DISPLAY
	cfTimeDisplayMask = application.ptCalendar.getDisplayCFtimeMask(); 			// "h:mm tt" - TIME FORMAT FOR DISPLAY
	
	// Set the Event Cache status from the configuration element
	useEventsCache = application.ptCalendar.getEventCacheStatus();
	
	// Get the items from the Display Properties Custom Element
	items = attributes.elementInfo.elementData.propertyValues;
	
	linkedCalendarPage = "";
	linkedCalendarSubsite = "";
	if ( ArrayLen(items) AND StructKeyExists(items[1],"values") ) 
	{
		if ( StructKeyExists(items[1].values,"linkedCalendarPage") )
			linkedCalendarPage = application.ptCalendar.csData.parseCSURL(str=items[1].values.linkedCalendarPage);
		if ( StructKeyExists(items[1].values,"linkedCalendarSubsite") )
			linkedCalendarSubsite = items[1].values.linkedCalendarSubsite;
			
		//WriteDump(items[1].values);
	}

	// - ptCalendar EventsCache designation (generally this will be true. May need to set to false for debugging)
	// useEventsCache = false; // (true/false) - Use this as an override for the Global setting that is managed via the Configuration element
	
	/* ** getRenderUpcomingEventsData  *** */
	// ptCalendar date and data processing returned as CF query object
	//  -- THIS MUST BE INCLUDED AT THE TOP OF THE ptCalendar Upcoming Events RenderHandler (after the getRenderEventData Settings)
	eventData = application.ptCalendar.calRenderController.getRenderDateRangeEventsData(
																	displayPropsArray=items
																	,useEventsCache=useEventsCache
																);
																
//application.ptCalendar.utils.doDump(items,"items",0);
//application.ptCalendar.utils.doDump(eventData,"eventData",1);
	
	// Get the view link data structure
	if ( application.ptCalendar.viewPageMode EQ "Single" ) { 
		if ( LEN(TRIM(linkedCalendarPage)) )
			viewLinkData = application.ptCalendar.calRenderViewService.getCalViewPageStruct(pageURL=linkedCalendarPage);
		else
			viewLinkData = application.ptCalendar.calRenderViewService.getCalViewPageStruct();	
		qParamDelimiter = "&amp;";		
	}
	else {
		if ( LEN(TRIM(linkedCalendarSubsite)) )
			viewLinkData = application.ptCalendar.calPageMapDAO.getCalPageMapStruct(subsiteID=linkedCalendarSubsite);
		else
			viewLinkData = application.ptCalendar.calPageMapDAO.getCalPageMapStruct();
		qParamDelimiter = "?";
	}
	
	detailLink = "";
	dailyLink = "";
	weeklyListLink = "";
	weeklyGridLink = "";
	monthlyListLink = "";
	monthlyGridLink = "";

	if( structKeyExists(viewLinkData, "detailPage") and len(trim(viewLinkData.detailPage)) )
		detailLink = viewLinkData.detailPage;
	if( structKeyExists(viewLinkData, "dailyPage") and len(trim(viewLinkData.dailyPage)) )
		dailyLink = viewLinkData.dailyPage;
	if( structKeyExists(viewLinkData, "weeklyListPage") and len(viewLinkData.weeklyListPage) )
		weeklyListLink = viewLinkData.weeklyListPage;
	if( structKeyExists(viewLinkData, "weeklyGridPage") and len(viewLinkData.weeklyGridPage) )
		weeklyGridLink = viewLinkData.weeklyGridPage;
	if( structKeyExists(viewLinkData, "monthlyListPage") and len(viewLinkData.monthlyListPage) )
		monthlyListLink = viewLinkData.monthlyListPage;
	if( structKeyExists(viewLinkData, "monthlyGridPage") and len(viewLinkData.monthlyGridPage) )
		monthlyGridLink = viewLinkData.monthlyGridPage;
	
	// Get the Default Calendar View Link
	defaultCalendarViewLink = monthlyGridLink;
	defaultViewPageVar = application.ptcalendar.calRenderViewDAO.getCalendarDefaultViewPageVar();
	if( structKeyExists(viewLinkData,defaultViewPageVar) and LEN(TRIM(viewLinkData[defaultViewPageVar])) )
		defaultCalendarViewLink = viewLinkData[defaultViewPageVar];
</cfscript>

<!--- // Render the Upcoming Events List --->
<cfoutput>
	<cfif not arrayLen(eventData)>
		<div class="uc-event-name no-events">No upcoming events</div>
	<cfelse>
		<cfloop from="1" to="#arrayLen(eventData)#" index="itm">
			<!--- // Build the event details link with URL params for the occurrence --->
			<!--- // There may be many Event Records with the the same calEventID (recurring events or an event with multiple date times) --->
			<!--- // - Each ocurrence of a recurring event gets a unique dtHashID --->
			<!--- // - Each "date/time" record for an event gets a unique dateTimeID --->
			<cfset linkParamsData = application.ptCalendar.calRenderService.buildEventDetailsLinksParams(eventDataStruct=eventData[itm])>
			<cfset eventDetailLink = application.ptCalendar.calRenderService.buildLinkParamURL(
																							linkURL=detailLink
																							,linkParamName=linkParamsData.UIDvarName
																							,linkParamValue=linkParamsData.UIDvalue
																							,urlParams=""
																						)>
			<cfset eventLayerID = linkParamsData.UIDstring>

			<div class="day-list-wrapper">

				<div id="#eventLayerID#">
					
					<!--- // Build Time String for this event occurrence --->
					<cfsavecontent variable="timeStr">
					<cfoutput>
						<cfif StructKeyExists(eventData[itm],"AllDay") AND eventData[itm].AllDay EQ 1>
							<span class="all-day-open">[</span>ALL DAY<span class="all-day-close">]</span>
						<cfelseif StructKeyExists(eventData[itm],"startTime") AND LEN(TRIM(eventData[itm].startTime))>
							#timeFormat(eventData[itm].startTime, cfTimeDisplayMask)#<cfif StructKeyExists(eventData[itm],"endTime") AND LEN(TRIM(eventData[itm].endTime))> - #timeFormat(eventData[itm].endTime, cfTimeDisplayMask)#</cfif>
						</cfif>
					</cfoutput>
					</cfsavecontent>
	
					<!--- // Output Time String --->
					<!--- <cfif LEN(TRIM(timeStr))>
						<div class="event-header">#timeStr#</div><!--- class="event-time" --->
					</cfif> --->
					
					<!--- // Build Date String --->
					<cfset dateStr = DateFormat(eventData[itm].eventDate,"mm/dd/yyyy")>
					
					<!--- // Output Event Name and Detail Link with or without tooltip --->
					<div class="uc-event-item">
						<!--- // Output Date String --->
						<cfif LEN(TRIM(dateStr))>
							<span class="uc-event-date">#dateStr#</span>
						</cfif> 
						<span class="uc-event-name">
							<a href='#eventDetailLink#'>#eventData[itm].title#</a>
							<cfif StructKeyExists(eventData[itm],"dateTimeID") AND StructKeyExists(eventData[itm],"dthashID")>
								<cfif LEN(TRIM(eventData[itm].dateTimeID)) AND LEN(TRIM(eventData[itm].dthashID))>
									&nbsp;<img alt="[R*]" title="Broken Recurrence" width="9" height="8" src="/ADF/apps/pt_calendar/images/broken_recurr1.png" /><!--- // [R*] Broken Recurrence --->
								<cfelseif LEN(TRIM(eventData[itm].dthashID)) AND LEN(TRIM(eventData[itm].dateTimeID)) EQ 0>
									&nbsp;<img alt="[R]" title="Recurring Event" width="9" height="8" src="/ADF/apps/pt_calendar/images/recurrence1.png" /><!--- [R] - Recurrence --->
								</cfif>
							</cfif>
						</span>
						<!--- // Output Time String --->
						<cfif LEN(TRIM(timeStr))>
							<span class="uc-event-time">#timeStr#</span>
						</cfif> 
					</div>

				</div>
				
			</div>
		</cfloop>
	</cfif>
	<!--- // Display the Full Calendar View Link --->
	<cfif LEN(TRIM(defaultCalendarViewLink))>
	<div class="full-calendar-link">
		<a href="#defaultCalendarViewLink#">Full Calendar</a>
	</div>
	</cfif>
</cfoutput>